/* Sistemas Integrados TECNISA

Nome: 5059_FISTRGO.SQL

Descrio:
   Trigger para gravar o log das alteraes

Criao:
   04/12/2012 - Marcelo Alexsandro

Tabela CFOPNCMREGRAFIS: CFOP por NCM da Regra Fiscal.
Descrio: A trigger insere registros na tabela LOGREGRAFISCAL a partir de alteraes na tabela CFOPNCMREGRAFIS
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_FIS_CFOPNCMREGRAFIS' AND
                 TYPE   = 'TR' 	           AND
	              U.UID  = O.UID             AND
	              U.NAME = USER)
DROP TRIGGER LOG_FIS_CFOPNCMREGRAFIS
GO

CREATE TRIGGER LOG_FIS_CFOPNCMREGRAFIS
ON CFOPNCMREGRAFIS
FOR INSERT, UPDATE, DELETE
AS
   DECLARE @V_USUARIO    VARCHAR(40);
   DECLARE @V_DTOPER     DATETIME;

   DECLARE @V_ID_COMANDO VARCHAR(1);
   DECLARE @V_DESC       VARCHAR(350);
   DECLARE @V_ITPESQ     VARCHAR(40);
   DECLARE @V_NMOPERADOR VARCHAR(40);
   DECLARE @V_IDTIPOOPER VARCHAR(1);

   DECLARE @V_CDREGRAFISC_OLD      VARCHAR(10)
   DECLARE @V_CDCLASFISC_OLD        VARCHAR(10)
   DECLARE @V_CDFISCOPER_OLD       VARCHAR(10)
   DECLARE @V_IDCFOPINTEREST_OLD   VARCHAR(1)
   DECLARE @V_IDDIFEALIQ_OLD       VARCHAR(1)
   DECLARE @V_IDDIFALIQCUSPR_OLD   VARCHAR(1)

   DECLARE @V_CDREGRAFISC_NEW      VARCHAR(10)
   DECLARE @V_CDCLASFISC_NEW        VARCHAR(10)
   DECLARE @V_CDFISCOPER_NEW       VARCHAR(10)
   DECLARE @V_IDCFOPINTEREST_NEW   VARCHAR(1)
   DECLARE @V_IDDIFEALIQ_NEW       VARCHAR(1)
   DECLARE @V_IDDIFALIQCUSPR_NEW   VARCHAR(1)


BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/
   SET @V_DESC       = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO @V_NMOPERADOR;
   SET @V_NMOPERADOR = ISNULL(@V_NMOPERADOR, '');

   DECLARE C_CURSOR CURSOR FOR
   SELECT
     'D' IDCOMANDO,
     DELETED.CDREGRAFISC,
     DELETED.CDCLASFISC,
     DELETED.CDFISCOPER,
     DELETED.IDCFOPINTEREST,
     DELETED.IDDIFEALIQ,
     DELETED.IDDIFALIQCUSPR,
     NULL,
     NULL,
     NULL,
     NULL,
     NULL,
     NULL
   FROM
     DELETED
   WHERE CDREGRAFISC+CDCLASFISC+IDCFOPINTEREST NOT IN (SELECT CDREGRAFISC+CDCLASFISC+IDCFOPINTEREST FROM INSERTED)

   UNION ALL

   SELECT
     'U' IDCOMANDO,
     DELETED.CDREGRAFISC,
     DELETED.CDCLASFISC,
     DELETED.CDFISCOPER,
     DELETED.IDCFOPINTEREST,
     DELETED.IDDIFEALIQ,
     DELETED.IDDIFALIQCUSPR,
     INSERTED.CDREGRAFISC,
     INSERTED.CDCLASFISC,
     INSERTED.CDFISCOPER,
     INSERTED.IDCFOPINTEREST,
     INSERTED.IDDIFEALIQ,
     INSERTED.IDDIFALIQCUSPR
   FROM
      INSERTED,
      DELETED
   WHERE INSERTED.CDREGRAFISC = DELETED.CDREGRAFISC
     AND INSERTED.CDCLASFISC = DELETED.CDCLASFISC
     AND INSERTED.IDCFOPINTEREST = DELETED.IDCFOPINTEREST

   UNION ALL

   SELECT
     'I' IDCOMANDO,
     NULL,
     NULL,
     NULL,
     NULL,
     NULL,
     NULL,
     INSERTED.CDREGRAFISC,
     INSERTED.CDCLASFISC,
     INSERTED.CDFISCOPER,
     INSERTED.IDCFOPINTEREST,
     INSERTED.IDDIFEALIQ,
     INSERTED.IDDIFALIQCUSPR
   FROM INSERTED
   WHERE CDREGRAFISC+CDCLASFISC+IDCFOPINTEREST NOT IN (SELECT CDREGRAFISC+CDCLASFISC+IDCFOPINTEREST FROM DELETED);

   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                 @V_CDREGRAFISC_OLD,
                                 @V_CDCLASFISC_OLD,
                                 @V_CDFISCOPER_OLD,
                                 @V_IDCFOPINTEREST_OLD,
                                 @V_IDDIFEALIQ_OLD,
                                 @V_IDDIFALIQCUSPR_OLD,
                                 @V_CDREGRAFISC_NEW,
                                 @V_CDCLASFISC_NEW,
                                 @V_CDFISCOPER_NEW,
                                 @V_IDCFOPINTEREST_NEW,
                                 @V_IDDIFEALIQ_NEW,
                                 @V_IDDIFALIQCUSPR_NEW;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF @V_ID_COMANDO = 'U' BEGIN
         SET @V_DESC   = 'CFOP = '                         + @V_CDFISCOPER_NEW     + ' ' +
                         'Interestadual = '                + @V_IDCFOPINTEREST_NEW + ' ' +
                         'Dif. Aliq. = '                   + @V_IDDIFEALIQ_NEW     + ' ' +
                         'Dif. Aliq. no Cust. do Prod. = ' + @V_IDDIFALIQCUSPR_NEW;
         SET @V_ITPESQ = @V_CDREGRAFISC_NEW+@V_CDCLASFISC_NEW+@V_IDCFOPINTEREST_NEW;
         SET @V_IDTIPOOPER = '2';
      END
      ELSE BEGIN
         IF @V_ID_COMANDO = 'I' BEGIN
            SET @V_DESC   = 'CFOP = '                         + @V_CDFISCOPER_NEW     + ' ' +
                            'Interestadual = '                + @V_IDCFOPINTEREST_NEW + ' ' +
                            'Dif. Aliq. = '                   + @V_IDDIFEALIQ_NEW     + ' ' +
                            'Dif. Aliq. no Cust. do Prod. = ' + @V_IDDIFALIQCUSPR_NEW;
            SET @V_ITPESQ = @V_CDREGRAFISC_NEW+@V_CDCLASFISC_NEW+@V_IDCFOPINTEREST_NEW;
            SET @V_IDTIPOOPER = '1';
         END
         ELSE BEGIN
            IF @V_ID_COMANDO = 'D' BEGIN
            SET @V_DESC   = 'CFOP = '                         + @V_CDFISCOPER_OLD     + ' ' +
                            'Interestadual = '                + @V_IDCFOPINTEREST_OLD + ' ' +
                            'Dif. Aliq. = '                   + @V_IDDIFEALIQ_OLD     + ' ' +
                            'Dif. Aliq. no Cust. do Prod. = ' + @V_IDDIFALIQCUSPR_OLD;
               SET @V_ITPESQ = @V_CDREGRAFISC_OLD+@V_CDCLASFISC_OLD+@V_IDCFOPINTEREST_OLD;
               SET @V_IDTIPOOPER = '3';
            END;
         END;
      END;
      INSERT INTO LOGREGRAFISCAL
         (NMTABELA,
          DTOPERACAO,
          NMRESPOPER,
          IDTIPOOPER,
          DSOPERACAO,
          CDPESQITEM)
       VALUES
         ('CFOPNCMREGRAFIS',
          GETDATE(),
          ISNULL(@V_NMOPERADOR,' '),
          @V_IDTIPOOPER,
          @V_DESC,
          @V_ITPESQ);
      FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                    @V_CDREGRAFISC_OLD,
                                    @V_CDCLASFISC_OLD,
                                    @V_CDFISCOPER_OLD,
                                    @V_IDCFOPINTEREST_OLD,
                                    @V_IDDIFEALIQ_OLD,
                                    @V_IDDIFALIQCUSPR_OLD,
                                    @V_CDREGRAFISC_NEW,
                                    @V_CDCLASFISC_NEW,
                                    @V_CDFISCOPER_NEW,
                                    @V_IDCFOPINTEREST_NEW,
                                    @V_IDDIFEALIQ_NEW,
                                    @V_IDDIFALIQCUSPR_NEW;
   END;
   CLOSE C_CURSOR;
   DEALLOCATE C_CURSOR;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_FIS_CFOPNCMREGRAFIS','5.30.xxx';
GO
